@@ -1,55 +1,55 @@
 #-*- coding: utf-8 --
+EVB_MAGIC = b'EVB\x00'
+
 EVB_PACK_HEADER = [
     ('4s', 'signature'),   # Would always be ('EVB\x00') if valid
-    64
+    ('60s',''),    
 ]
 
 EVB_CHUNK_BLOCK = [
     ('I','size'),
     ('I',''),    
-    8
 ]
 
 EVB_HEADER_NODE = [
     ('I','size'),
     ('8s',''),
     ('I','objects_count'),
-    16
 ]
 
 EVB_NODE_MAIN = [
     ('I', 'size'),
-    ('6s', ''), # don't know what this is for
+    ('8s', ''),
     ('I', 'objects_count'),
-    14
 ]
 
 EVB_NODE_NAMED = [    
     ('%ds', 'name'), # args[0] - filename buffer length
     ('2s', ''),
     ('B', 'type'),
-    3  # the length of the 2s + type
 ]
 
 EVB_NODE_OPTIONAL_FILE = [
     ('2s', ''),
     ('I', 'original_size'),
     ('4s',''),
-    ('24s','filetime'),
+    ('8s','filetime1'),
+    ('8s','filetime2'),
+    ('8s','filetime3'),
     ('15s',''),
     ('I', 'stored_size'),
-    53
 ]
 
 EVB_NODE_OPTIONAL_PE_FILE = [
     ('2s', ''),
     ('I', 'original_size'),
     ('4s',''),
-    ('24s','filetime'),
+    ('8s','filetime1'),
+    ('8s','filetime2'),
+    ('8s','filetime3'),
     ('7s',''),
     ('I', 'stored_size'),
     ('4s',''),
-    49 
 ]
 
 NODE_TYPE_MAIN   = 0
